#
# spec file for package perl-DBIx-Class-Schema-Loader
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBIx-Class-Schema-Loader
Name:           perl-DBIx-Class-Schema-Loader
Version:        0.07052
Release:        1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Create a DBIx::Class::Schema based on a database
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/V/VE/VEESH/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Carp::Clan)
BuildRequires:  perl(Class::Accessor::Grouped) >= 0.10008
BuildRequires:  perl(Class::C3::Componentised) >= 1.0008
BuildRequires:  perl(Class::Inspector) >= 1.27
BuildRequires:  perl(Class::Unload) >= 0.07
BuildRequires:  perl(DBD::SQLite) >= 1.29
BuildRequires:  perl(DBIx::Class) >= 0.08127
BuildRequires:  perl(Data::Dump) >= 1.06
BuildRequires:  perl(Exporter) >= 5.63
BuildRequires:  perl(File::Path) >= 2.07
BuildRequires:  perl(Hash::Merge) >= 0.12
BuildRequires:  perl(Lingua::EN::Inflect::Number) >= 1.1
BuildRequires:  perl(Lingua::EN::Inflect::Phrase) >= 0.15
BuildRequires:  perl(Lingua::EN::Tagger) >= 0.23
BuildRequires:  perl(List::Util) >= 1.33
BuildRequires:  perl(MRO::Compat) >= 0.09
BuildRequires:  perl(Scope::Guard) >= 0.20
BuildRequires:  perl(String::CamelCase) >= 0.04
BuildRequires:  perl(String::ToIdentifier::EN) >= 0.05
BuildRequires:  perl(Sub::Util) >= 1.40
BuildRequires:  perl(Test::Deep) >= 0.107
BuildRequires:  perl(Test::Differences) >= 0.60
BuildRequires:  perl(Test::Exception) >= 0.31
BuildRequires:  perl(Test::More) >= 0.94
BuildRequires:  perl(Test::Warn) >= 0.21
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(curry) >= 1.000000
BuildRequires:  perl(namespace::clean) >= 0.23
Requires:       perl(Carp::Clan)
Requires:       perl(Class::Accessor::Grouped) >= 0.10008
Requires:       perl(Class::C3::Componentised) >= 1.0008
Requires:       perl(Class::Inspector) >= 1.27
Requires:       perl(Class::Unload) >= 0.07
Requires:       perl(DBIx::Class) >= 0.08127
Requires:       perl(Data::Dump) >= 1.06
Requires:       perl(Exporter) >= 5.63
Requires:       perl(Hash::Merge) >= 0.12
Requires:       perl(Lingua::EN::Inflect::Number) >= 1.1
Requires:       perl(Lingua::EN::Inflect::Phrase) >= 0.15
Requires:       perl(Lingua::EN::Tagger) >= 0.23
Requires:       perl(List::Util) >= 1.33
Requires:       perl(MRO::Compat) >= 0.09
Requires:       perl(Scope::Guard) >= 0.20
Requires:       perl(String::CamelCase) >= 0.04
Requires:       perl(String::ToIdentifier::EN) >= 0.05
Requires:       perl(Sub::Util) >= 1.40
Requires:       perl(Try::Tiny)
Requires:       perl(curry) >= 1.000000
Requires:       perl(namespace::clean) >= 0.23
%{perl_requires}

%description
DBIx::Class::Schema::Loader automates the definition of a
DBIx::Class::Schema by scanning database table definitions and setting up
the columns, primary keys, unique constraints and relationships.

See dbicdump for the 'dbicdump' utility.

DBIx::Class::Schema::Loader currently supports only the DBI storage type.
It has explicit support for DBD::Pg, DBD::mysql, DBD::DB2, DBD::Firebird,
DBD::InterBase, DBD::Informix, DBD::SQLAnywhere, DBD::SQLite, DBD::Sybase
(for Sybase ASE and MSSSQL), DBD::ODBC (for MSSQL, MSAccess, Firebird and
SQL Anywhere) DBD::ADO (for MSSQL and MSAccess) and DBD::Oracle. Other DBI
drivers may function to a greater or lesser degree with this loader,
depending on how much of the DBI spec they implement, and how standard
their implementation is.

Patches to make other DBDs work correctly welcome.

See DBIx::Class::Schema::Loader::DBI::Writing for notes on writing your own
vendor-specific subclass for an unsupported DBD driver.

This module requires DBIx::Class 0.08127 or later, and obsoletes the older
DBIx::Class::Loader.

See DBIx::Class::Schema::Loader::Base for available options.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Jan  7 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.07052
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07052 - 2024-01-06
  - fix: don't load Test::More in ::Utils
* Thu Nov 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.07051
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07051 - 2022-11-23
  - Make defaulting primary key columns retrieve_on_insert for Pg (GH#28)
  0.07050 - 2022-11-20
  - Revert inlining of String::CamelCase::wordsplit() (RT#125929)
  - Do not require MooseX::MarkAsMethods with only_autoclean=1 (GH#21)
  - Exclude tables in the Oracle Recycle Bin (RT#128149)
* Thu Mar 22 2018 coolo@suse.com
- updated to 0.07049
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07049 - 2018-03-21
  - Fix tests when the path to perl has spaces in it (GH#19)
  - Inline String::CamelCase::wordsplit() due to RT#123030
  - Get enum values from DBD::Pg if it's new enough
  - Remove dependency on DBIx::Class::IntrospectableM2M
  0.07048_01 - 2018-02-23
  - Convert from Module::Install to ExtUtils::MakeMaker + Distar (GH#17)
* Sun Jan 21 2018 coolo@suse.com
- updated to 0.07048
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07048  2018-01-20
  - Fix for PostgreSQL enums not in the schema search path (RT#123234)
  - Fix 'default now()' test for PostgreSQL v10
  - Work around incompatible change in Hash::Merge (GH#16)
  - Fix skip count for non-InnoDB MySQL test
* Sat May 27 2017 coolo@suse.com
- updated to 0.07047
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07047  2017-05-26
  - Avoid upcoming DBIC warning on implicit SELECT * invocation
    (RT#118178)
  - Improve moniker_map and col_accessor_map coderef documentation (GH#7)
  - Improve exclude and constraint documentation (GH#12)
  - Fix running Makefile.PL without '.' in @INC (RT#121905)
* Tue Sep  6 2016 coolo@suse.com
- updated to 0.07046
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07046  2016-09-05
  - Introspect view definitions for PostgreSQL, MySQL, Oracle,
    Firebird, and InterBase.
  - When a file's md5sum was wrong but no other content in the file had
    changed, it would not be rewritten even when overwrite_modifications
    was true. Fixed by Dave Rolsky. GH #8.
* Wed Jan 27 2016 coolo@suse.com
- updated to 0.07045
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07045  2016-01-22
  - Regenerate tarball without author-mode test dependencies
  0.07044  2016-01-22
  - Fix Pg date/time types with zero fractional second digits
  - Add support for nested hashref form of col_accessor_map
* Sun May 17 2015 coolo@suse.com
- updated to 0.07043
  see /usr/share/doc/packages/perl-DBIx-Class-Schema-Loader/Changes
  0.07043  2015-05-13
  - Fix many_to_many bridges with overlapping foreign keys
  - Add option to allow extra columns in many_to_many link tables
  - Document how to add perltidy markers via filter_generated_code
  - Fix DB2 foreign-key introspection
  - Remove dependency on List::MoreUtils and Sub::Name
  - Ensure schema files are generated as binary files on Windows
  - Fix overwrite_modifications not overwriting if the table hasn't changed
  - Filter out disabled constraints and triggers for Oracle (GH#5)
  0.07042  2014-08-20
* Tue Dec  2 2014 coolo@suse.com
- updated to 0.07042
  - Fix unescaped left braces in regexes in tests
  - Use undef instead of '%%' for the table and type arguments
    to $dbh->tables (fixes breakage with DBD::Pg 3.4.0)
  0.07041  2014-08-09
  - Fix many_to_many bridges going back to the same table
  - Don't disconnect after ->load in static mode
    (fixes Pg test failure with the upcoming DBIC 0.082800)
  - Set up Travis smoking (mostly stolen from DBIC)
  0.07040  2014-05-27
  - Add options to omit the version and timestamp from the
    generated code (RT#92300)
  - Skip dumping unique indexes with expressions (RT#93613)
  - Fix dumping unique indexes with DBD::Pg < 1.50
  - Fix inconsistent naming of duplicate unique constraints
  - Avoid clobbering caller's $_ (RT#96010)
  0.07039  2014-01-06
  - Fix table listing with DBD::DB2 >= 1.85 (RT#91764)
  - Add accessor for the list of (re)generated classes
  - Add dry-run mode for static schema creation
  0.07038  2013-11-20
  - Allow coderef maps to call back into the hashref mapping code
  - Fix MySQL column info detection with multiple schemas (RT#82358)
  - Fix skip count for Oracle multi-schema tests
  - Actually test data types that require separate tables
  - Fix national character type sizes on DBD::Oracle >= 1.52
  - Fix detection of qualified sequence names for Oracle (RT#90341)
  0.07037  2013-10-30
  - Allow overriding individual moniker parts
  0.07036_04 2013-10-24
  - Set table_class to DBIx::Class::ResultSource::View for views, in
    supported backends (SQLite, MySQL, and Pg) (arc@cpan.org)
  0.07036_03 2013-10-22
  - Restore support for PostgreSQL 8.3 (RT#87291)
  - Fix t/23dumpmore on perl 5.8.8 and earlier
  - Silence warnings from pure-perl Cwd::abs_path()
  0.07036_02 2013-09-25
  - Skip many_to_many bridges involving might_have relationships
  0.07036_01 2013-08-11
  - Fix typos in POD and comments (RT#87644)
  - Don't ship MYMETA.* files (RT#87713)
  - Fix many_to_many bridges involving might_have relationships
  - Allow specifying custom attributes for many_to_many bridges
  - Allow specifying the separator when joining database, schema
    and table names to form a moniker
  - Allow using all the moniker parts in hashref moniker_map
  - Allow matching all the moniker parts in constraint/exclude
* Fri Jun  1 2012 coolo@suse.com
- updated to 0.07024
  - work around broken keyseq in DBD::Pg foreign_key_info (RT#77062)
  - properly order FK columns when using base ::DBI loader (SineSwiper)
  - bump Class::Inspector dep to 1.27 due to test failures with earlier
    versions on perl >= 5.15.7 (RT#74236)
  - do separate queries for default_value on Sybase ASE as some servers
    can't join to that table (pcmantz) (RT#74170)
  - set correct size for nchar/nvarchar columns for Sybase ASE,
    depending on @@ncharsize
  - use ::Schema::connect instead of ::Schema::connection in
    make_schema_at (RT#74175)
  - register sources on the schema class, never the instance, regardless
    of how the connection is made for dynamic schemas
  - fix some mro issues under perl 5.8
  - fix some errors due to case issues (RT#75805)
  - skip dbicdump tests on Win32 due to test fails (RT#75732)
  - fix undefined warnings for DBDs without schemas
  - work around ORA-24345 from $dbh->column_info
  - fix spelling mistake in Base POD (RT#74796)
  - *EXPERIMENTAL* support for dumping PostgreSQL schemas inside of a
    transaction
  - use DBI table_info/column_info REMARKS field if/where available for
    table/column comments (SineSwiper)
  - better compatibility with more DBDs (SineSwiper)
* Fri Jan 13 2012 coolo@suse.com
- updated to 0.07015
  - generate many_to_many bridges for targets of link tables
  - fix a bug in the automatic multischema clashing moniker disambiguation
    code that overwrote $loader->moniker_parts
  - automatically prefix database/schema to clashing monikers for
    the same table name in multischema configurations
* Fri Jan 13 2012 coolo@suse.com
- update to 0.07012, see Changes
* Thu Apr 21 2011 coolo@opensuse.org
- updated to 0.07010
  - add result_component_map option
  - fix a syntax error in MS Access ADO driver
  - rename column_accessor_map to col_accessor_map, the old alias still
    works
  - support MSSQL over DBD::ADO
  - support for MS Access over DBD::ODBC and DBD::ADO
  - bump DBIx::Class dep to 0.08127
  - fix MSSQL data types for native client and EasySoft driver
  - turn unloading of RelBuilder temp classes back on, now with proper
    check for class existance using Class::Inspector->loaded
  - bump up dep on namespace::clean to avoid breakage with earlier
    versions (RT#65149)
  - support extra connect_info options like quote_char for dbicdump
  - fix breakage on perl 5.8.x related to unloading temporary classes
  - fix bug with result class methods being cached on in a closure instead
    of the object, which breaks for multiple dynamic schemas in a single
    perl instance
  - fix relname/method collisions (RT#62648)
  - fix fully qualified component classes (RT#62624)
  - improve sybase/mssql db_schema detection
  - remove MooseX::NonMoose from Schema files under use_moose=1
  - better _tables_list for Sybase ASE
  - add datetime_undef_if_invalid => 1 for MySQL datetime data types
    (RT#64820) This behavior can be turned off by passing
    datetime_undef_if_invalid=0 as a loader option
  - added column_accessor_map option
  - Preserve relationship names when redumping and another FK is added
    (RT#62424)
  - Remove resultset_components as ResultSetManager is deprecated
  - Fix a fail when very old Moose/CMOP is installed
  - Added warning for column-accessor collisions, doc section in ::Base
    ("COLUMN ACCESSOR COLLISIONS") and the col_collision_map option.
  - Handle column accessor collisions with UNIVERSAL methods
  - Generate custom_type_name hint for PostgreSQL enums, as used
    by very recent SQL::Translator
  - Added support for PostgreSQL enum types
  - Added table/column comment support for Oracle
  - Fix missing require (RT#62072)
* Mon Jan 17 2011 coolo@novell.com
- initial package 0.07002
  * created by cpanspec 1.78.03
